@@ -31,15 +31,20 @@ class Client(object):
 
 
     def get(self, model_id: str, limit: int = 100) -> pandas.DataFrame:
+        '''
+        Retrieve `limit` records from the specified model, and return a dataframe. The default
+        limit is 100 records.
+        '''
         if self.access_token is None:
             self._auth()
         
         url = '{}/{}?limit={}'.format(urls['Fetch'], model_id, limit)
         resp = requests.get(url, headers={
-            'Authorization': 'Bearer %s'.format(self.access_token)
+            'Authorization': 'Bearer {}'.format(self.access_token)
         })
 
         if resp.ok:
-            return pandas.DataFrame(resp.json())
+            data = resp.json()['data']
+            return pandas.DataFrame(data)
         else:
             raise resp.raise_for_status()
\ No newline at end of file
